@@ -257,7 +257,7 @@ def sliceobj(expression: Union[int, str, slice], variables: Optional[dict] = Non
     return slice(*sliced)
 
 
-def utf8(x):
+def utf8(x: str):
     """
     Returns the UTF8 encoding of the given string.
     """
@@ -409,41 +409,90 @@ def LazyPythonExpression(expression: str) -> MaybeDelayedType[Any]:
 
 class DelayedArgument(LazyEvaluation):
     """
-    This base class for delayed argument parsers implements parsing
-    expressions into supported modifiers.
+    This base class for delayed argument parsers implements parsing expressions into supported modifiers.
+    When `reverse` is set to `True`, the multibin expression is expected to have suffixes for handlers
+    rather than prefixes. If the `seed` value is specified, the expression is expected to only contain
+    a chain of handlers, and the given seed will be used as the initial value to be passed to them.
     """
     _ARG_BEGIN_TOKEN = '['
     _ARG_CLOSE_TOKEN = ']'
     _ARG_SPLIT_TOKEN = ','
+    _CMD_SPLIT_TOKEN = ':'
 
-    def __init__(self, expression: str):
+    def __init__(self, expression: str, reverse: bool = False, seed=None):
         self.expression = expression
         self.modifiers = []
         self.finalized = False
+        if seed is not None:
+            if reverse:
+                if not expression.startswith(':'):
+                    expression = F':{expression}'
+            else:
+                if not expression.endswith(':'):
+                    expression = F'{expression}:'
         while not self.finalized:
-            name, arguments, newexpr = self._split_modifier(expression)
+            name, arguments, newexpr = self._split_modifier(expression, reverse)
             if not name or not self.handler.can_handle(name, *arguments):
                 break
             self.modifiers.append((name, arguments))
             expression = newexpr
             if self.handler.terminates(name):
                 self.finalized = True
-        self.seed = expression
+        if seed is not None:
+            if expression:
+                raise ValueError('Expression was not fully parsed.')
+            self.seed = seed
+        else:
+            self.seed = expression
         self.modifiers.reverse()
 
-    def _split_modifier(self, expression: str) -> Tuple[Optional[str], Tuple[str], str]:
+    def _split_expression(self, expression: str, reverse: bool = False) -> Tuple[str, Optional[str]]:
+        argument_list_visited = False
         brackets = 0
-        name = None
-        argoffset = 0
-        arguments = ()
-        for k, character in enumerate(expression):
-            if character == self._ARG_BEGIN_TOKEN:
+        inc = self._ARG_BEGIN_TOKEN
+        dec = self._ARG_CLOSE_TOKEN
+        itx = enumerate(expression)
+        if reverse:
+            inc, dec = dec, inc
+            itx = reversed(list(itx))
+        for k, character in itx:
+            if character == inc:
                 if not brackets:
-                    if argoffset:
+                    if argument_list_visited:
                         # This is the second time we encounter what appears to be an
                         # argument list, before the modifier has ended. This is not
                         # possible, and we decide to assume that no modifier was used.
                         break
+                    argument_list_visited = True
+                brackets += 1
+                continue
+            if character == dec:
+                if not brackets:
+                    break
+                brackets -= 1
+                continue
+            if not brackets and character == self._CMD_SPLIT_TOKEN:
+                head = expression[:k]
+                tail = expression[k + 1:]
+                return (head, tail) if reverse else (tail, head)
+        return expression, None
+
+    def _split_modifier(self, expression: str, reverse: bool = False) -> Tuple[Optional[str], Tuple[str], str]:
+        brackets = 0
+        name = None
+        argoffset = 0
+        arguments = ()
+
+        rest, expression = self._split_expression(expression, reverse)
+        if expression is None:
+            return name, arguments, rest
+        name = expression
+
+        for k, character in enumerate(expression):
+            if character == self._ARG_BEGIN_TOKEN:
+                if not brackets:
+                    if argoffset:
+                        raise ArgumentTypeError(F'Unexpected error parsing "{expression}": Double argument list.')
                     name = expression[:k]
                     argoffset = k + 1
                 brackets += 1
@@ -453,9 +502,7 @@ class DelayedArgument(LazyEvaluation):
                     arguments += expression[argoffset:k],
                 elif not brackets:
                     if argoffset:
-                        raise ArgumentTypeError(
-                            F'Unable to parse {expression}, too many closing brackets.'
-                        )
+                        raise ArgumentTypeError(F'Unable to parse "{expression}": Too many closing brackets.')
                     else:
                         break
                 brackets -= 1
@@ -464,11 +511,9 @@ class DelayedArgument(LazyEvaluation):
                 if brackets == 1:
                     arguments += expression[argoffset:k],
                     argoffset = k + 1
-            if character == ':' and not brackets:
-                if name is None:
-                    name = expression[:k]
-                return name, arguments, expression[k + 1:]
-        return None, (), expression
+            if character == self._CMD_SPLIT_TOKEN and not brackets:
+                raise ArgumentTypeError(F'Unexpected error parsing "{expression}".')
+        return name, arguments, rest
 
     def __call__(self, data: Optional[ByteString] = None) -> bytes:
         arg = self.seed
@@ -498,7 +543,11 @@ class DelayedArgument(LazyEvaluation):
         try:
             return open(expression, 'rb').read()
         except Exception:
+            pass
+        try:
             return utf8(expression)
+        except Exception:
+            return expression
 
     @DelayedArgumentDispatch
     def handler(self, expression) -> bytes:
@@ -526,6 +575,14 @@ class DelayedArgument(LazyEvaluation):
         """
         return string.encode('LATIN-1')
 
+    @handler.register('h!', 'H!')
+    def hexencode(self, string: bytes) -> bytes:
+        """
+        The modifier `h!` (or `H!`) encodes the input as hexadecimal.
+        """
+        import base64
+        return base64.b16encode(string)
+
     @handler.register('h', 'H', final=True)
     def h(self, string: str) -> bytes:
         """
@@ -1144,13 +1201,13 @@ def numseq(expression: Union[int, str], typecheck=True) -> Union[Iterable[int],
     return arg
 
 
-def multibin(expression: Union[str, bytes, bytearray]) -> Union[bytes, DelayedArgument]:
+def multibin(expression: Union[str, bytes, bytearray], reverse: bool = False, seed=None) -> Union[bytes, DelayedArgument]:
     """
     This is the argument parser type that uses `refinery.lib.argformats.DelayedBinaryArgument`.
     """
     if not isinstance(expression, str):
         return bytes(expression)
-    arg = DelayedBinaryArgument(expression)
+    arg = DelayedBinaryArgument(expression, reverse, seed)
     with suppress(TooLazy):
         return arg()
     return arg
