@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from codecs import encode, decode
+from functools import partial
 
 from refinery.units import arg, Unit
 from refinery.lib.meta import metavars
@@ -22,12 +23,13 @@ class cfmt(Unit):
 
     def __init__(
         self,
-        *formats: arg(help='Format strings.', type=str, metavar='format'),
-        put: arg('-p', type=str, metavar='NAME', help='Store the formatted string in a meta variable.') = None,
+        *formats : arg(help='Format strings.', type=str, metavar='format'),
+        variable : arg('-n', type=str, metavar='NAME', help='Store the formatted string in a meta variable.') = None,
         separator: arg('-s', group='SEP', metavar='S',
             help='Separator to insert between format strings. The default is a space character.') = ' ',
         multiplex: arg.switch('-m', group='SEP',
-            help='Do not join the format strings along the separator, generate one output for each.') = False
+            help='Do not join the format strings along the separator, generate one output for each.') = False,
+        binary   : arg.switch('-b', help='Use the binary formatter instead of the string formatter.') = False,
     ):
         def fixfmt(fmt):
             if not isinstance(fmt, str):
@@ -36,13 +38,19 @@ class cfmt(Unit):
         formats = [fixfmt(f) for f in formats]
         if not multiplex:
             formats = [fixfmt(separator).join(formats)]
-        super().__init__(formats=formats, put=put)
+        super().__init__(formats=formats, variable=variable, binary=binary)
 
     def process(self, data):
         meta = metavars(data, ghost=True)
-        name = self.args.put
+        args = [data]
+        variable = self.args.variable
+        if self.args.binary:
+            formatter = partial(meta.format_bin, codec=self.codec, args=args)
+        else:
+            def formatter(spec):
+                return meta.format_str(spec, self.codec, args).encode(self.codec)
         for spec in self.args.formats:
-            result = meta.format_str(spec, self.codec, [data]).encode(self.codec)
-            if name is not None:
-                result = self.labelled(data, **{name: result})
+            result = formatter(spec)
+            if variable is not None:
+                result = self.labelled(data, **{variable: result})
             yield result
